You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by si...@apache.org on 2012/07/04 12:23:54 UTC

svn commit: r1357213 - /commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/collections/DisjointSetNode.java

Author: simonetripodi
Date: Wed Jul  4 10:23:53 2012
New Revision: 1357213

URL: http://svn.apache.org/viewvc?rev=1357213&view=rev
Log:
s/e/element

Modified:
    commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/collections/DisjointSetNode.java

Modified: commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/collections/DisjointSetNode.java
URL: http://svn.apache.org/viewvc/commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/collections/DisjointSetNode.java?rev=1357213&r1=1357212&r2=1357213&view=diff
==============================================================================
--- commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/collections/DisjointSetNode.java (original)
+++ commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/collections/DisjointSetNode.java Wed Jul  4 10:23:53 2012
@@ -31,7 +31,7 @@ final class DisjointSetNode<E>
     /**
      * The stored node value.
      */
-    private final E e;
+    private final E element;
 
     /**
      * The {@code DisjointSetNode} parent node, {@code this} by default.
@@ -46,11 +46,11 @@ final class DisjointSetNode<E>
     /**
      * Creates a new {@link DisjointSet} node with the given value.
      *
      * @param e the node value has to be stored.
      */
-    public DisjointSetNode( E e )
+    public DisjointSetNode( E element )
     {
-        this.e = e;
+        this.element = element;
     }
 
     /**
@@ -60,7 +60,7 @@ final class DisjointSetNode<E>
      */
     public E getElement()
     {
-        return e;
+        return element;
     }
 
     /**
@@ -46,11 +46,11 @@ final class DisjointSetNode<E>
      * Creates a new {@link DisjointSet} node with the given value.
      *
-     * @param e the node value has to be stored.
+     * @param element the node value has to be stored.
      */